# pybazel

A python client for Bazel.

## Install

Pybazel is available as a [pypi package](https://pypi.org/project/pybazel/).

```shell
pip install pybazel
```

## Usage

```shell
python -c 'import pybazel; print(pybazel.BazelClient().info())'
```
